      subroutine pfile_info_pft (mode, ncol, nrow, nsec, nfiles, nids, 
     1     nids_tot, param_fnames, img_fnames, pixsize, inunit)

c     This routine had been renamed from pfile_info so as to avoid
c     conflict with the subroutine of the same name in the commpk
c     library developed by yongchang ji for the parallel codes. this
c     allows us to use commpk without conflicts
c
c     Reads in all parameter filenames and checks the corresponding
c     image files to be sure the image and model data have the same
c     dimensions.
c
c     Prompts user for a parameter data file, opens file, counts number
c     of particles, finds highest particle number, gets image filename
c     from first line of file.
c
c     adapted from pft_getpfile written by dmb, may 1995.             
c     
c     Modified 19-jan-1998 by t. baker (multiple inout files)  .        
c     Modified 22-jan-1998 by t. baker (ctf parameters).                
c     Modified  3-feb-1998 by t. baker (save img_filenames).            
c     Modified  6-mar-1998 by tsb (make unix compatible).               
c     Modified  5-may-1998 by tsb (pass min pixel size to info).        
c     Modified 25-aug-1999 by tsb (add units variable).            
c     Modified 1/8/2007 by rss - proper handling of blank lines,        
c     leading spaces in filenames, and pre-existing files               
c     plus some general cleanup and modernization                       
c     Modified 1/8/2007 by rss - More cleanup plus capability to handle
c     blank lines and commented lines

      implicit none

      integer, intent(in) :: inunit
      integer, intent(in)  :: mode, ncol, nrow, nsec
      integer, intent(out) :: nfiles, nids(999), nids_tot
      character(len=256), intent(out) :: param_fnames(999)
      character(len=256), intent(out) :: img_fnames(999)
      real, intent(out) :: pixsize      

      character(len=15) :: subname = 'pfile_info_pft'
      character(len=5)  :: progname = 'ppft'

      include '../include/pifhead.inc'
      type (pifhead_t) maphead, imghead, prjhead, pfthead
      common /pifhead/ maphead, imghead, prjhead, pfthead

      common/ctf_com/pixsiz, units, volts, amp_fac, focus_maj, 
     1     focus_min, ang_maj, cs_coeff

      integer nimg, id, loc, ios, i, j, units(999)
      real pixsiz(999), volts(999), amp_fac(999), focus_maj(999)
      real focus_min(999), ang_maj(999), cs_coeff(999)
      character(len=256) new_fname, fname
      character(len=26) upper_case, lower_case
 
      data upper_case /'abcdefghijklmnopqrstuvwxyz'/
      data lower_case /'abcdefghijklmnopqrstuvwxyz'/

      nfiles   = 0              ! count the number of parameter files
      nids_tot = 0              ! count the number of images to search
      pixsize  = 1000000.0      ! minimum pixel size 
      
      write(*,'(a)') 'Parameter data files: '

      do i = 1, 10000
         
C     Read parameter file name from standard input and check status  
C     ios < 0 : end of file reached, break out of loop
C     ios > 0 : error reading file, terminate program
         read (inunit, '(A)', iostat=ios) fname
         if(ios < 0) then
            exit
         else if (ios > 0) then
            call error_stop(progname,subname,
     +           'error reading parameter filename: exit program')
         endif
         
C     Get rid of leading spaces in parameter file name
         fname = trim(adjustl(fname))
         
C     Go to next iteration if blank line encountered
         if (fname(1:1) == ' ') cycle
         if (fname(1:1) == '#') cycle
         
C     Increment the file number
         nfiles = nfiles + 1

C     Make sure that maximum number of parameter files not exceeded
         if(nfiles > 999) then
            call error_stop(progname, subname,
     $           'more than 999 parameter files: exit program')
         endif
         
C     Open parameter file
         open (unit=2, file=fname, status='old', iostat=ios)
         if(ios .ne. 0) then
            call error_stop(progname, subname,
     $           'error opening parameter file: exit program')
         endif

C     Read image name
         read (2,'(a)',iostat=ios) img_fnames(nfiles)
         if(ios .ne. 0) then
            call error_stop(progname, subname,
     $           'error reading image filename: exit program')
         endif
         
c     The image file name may be specified with or without full path
c     information. For example /dir/subdir/image.pif or image.pif. To
c     allow greater flexibility, we first test to see if the image file
c     can be opened using the full path. If this fails, we then trim off
c     the path and try to open the file again.
         
c     get rid of leading whitspace in image file name
         img_fnames(nfiles) = adjustl(img_fnames(nfiles))
         
c     open the image file as specified in parameter file
         open(unit=25, file=img_fnames(nfiles), status='old',
     $        form='unformatted', iostat=ios)
         close(25)
         
c     test result of open. if failed, then try without path info
         if(ios == 0) then
            write(*,*) 'image file ok: ', trim(img_fnames(nfiles))
         else
            loc = index(img_fnames(nfiles), '/', .true.)
            img_fnames(nfiles) = img_fnames(nfiles)(loc+1:256)
            open(unit=25, file=img_fnames(nfiles), status='old',
     $           form='unformatted', iostat=ios)
            close(25)
            if(ios == 0) then
               write(*,*) 'image file path info removed: ',
     $              trim(img_fnames(nfiles))
            else
               call error_stop(progname,subname,
     $              'unable to open image file')
            endif
         endif
         
C     Get pixel size, units, etc. from second line of parameter file
         read (2,*,iostat=ios) pixsiz(nfiles), units(nfiles), 
     $        volts(nfiles), amp_fac(nfiles), focus_maj(nfiles), 
     $        focus_min(nfiles), ang_maj(nfiles), cs_coeff(nfiles)
         if(ios .ne. 0) then
            call error_stop(progname,subname,
     $           'error reading parameter file header: exit program')
         endif
            
C     Open image file and get header information. Make sure that leading
C     dimensions of map are the same as the dimensions of the images
         
         imghead%lunum = 7
         call pif_open (img_fnames(nfiles), imghead%lunum, 'r')
         call pif_read_gh (imghead)
         call pif_close (7)
         
         nimg  = imghead%nimg
         if(imghead%numcols.ne.ncol .or. imghead%numrows.ne.nrow) then
            write(*,*) 'ncol (map)   = ', ncol
            write(*,*) 'nrow (map)   = ', nrow
            write(*,*) 'nsec (map)   = ', nsec
            write(*,*) 'ncol (image) = ', imghead%numcols
            write(*,*) 'nrow (image) = ', imghead%numrows
            call error_stop(progname, subname,
     $           'Map size and image size are not equal')
         endif

C     Determine the number of particle images. If |mode|==1, use number
C     of images in PIF file. Otherwise, count number of particle records
C     in parameter file

         if(iabs(mode) == 1) then
            nids(nfiles) = nimg
         else
            nids(nfiles) = 0
            do j = 1, 100000
               read(2, *, iostat=ios) id
               if(ios < 0) exit
               nids(nfiles) = nids(nfiles) + 1
            enddo
         endif

         close(2)

         nids_tot = nids_tot + nids(nfiles)
         
C     Write warning if number parameter file is empty
         if(nids(nfiles) == 0) then
            write(*,*) 'Warning: file ', fname, ' is empty'
         endif

C     Increment parameter file name
         param_fnames(nfiles) = fname
         call increment_fname (param_fnames(nfiles), new_fname)
         if(pixsiz(nfiles).lt.pixsize) pixsize = pixsiz(nfiles)
         write(*,*)
         write(*,'(a,i4,2a)') ' file #', nfiles, ' is: ',
     $        img_fnames(nfiles)
         
      enddo

      write(*,'(i5,a,i6,a)') nfiles, ' parameter files and total of', 
     1     nids_tot, ' images for pft search.'

      return
      end subroutine pfile_info_pft
