/******************************************************************************
** array.h
** =======

Array Utility Routines
James Conway, LMES/IBS, Grenoble, France (email: James.Conway@ibs.fr)

06-Mar-2000: Add CopyArrayByteToFloat, CopyArrayFloatToByte
             Rename old CopyArrayFloatToByte to CopyArrayFloatToUByte
             Add GetStatsByteArray, rename old GetStatsByteArray to GetStatsUByteArray
07-Mar-2000: Add GetStatsWordArray and GetStatsUWordArray
09-Mar-2000: Add GetStatsFloatArray3, change "char" to "signed char"

******************************************************************************/

#ifndef __array_h__
#define __array_h__

double SumDoubleArray  (double *aptr, int count);
float  SumFloatArray   (float  *aptr, int count);
void   ZeroDoubleArray (double *aptr, int count);
void   ZeroFloatArray  (float  *aptr, int count);
double AvgDoubleArray  (double *aptr, int count);
float  AvgFloatArray   (float  *aptr, int count);

void   CopyArrayByteToFloat  (   signed char *src, float *dst, long size );
void   CopyArrayUByteToFloat ( unsigned char *src, float *dst, long size );
void   CopyArrayFloatToUByte ( float *src, unsigned char *dst, long size );
void   CopyArrayFloatToByte  ( float *src,   signed char *dst, long size );
void   CopyArrayShortToFloat ( short *src, float *dst, long size );
void   CopyArrayFloatToShort ( float *src, short *dst, long size );
void   CopyArrayFloatToFloat ( float *src, float *dst, long size );

void   AddFloatArrays        ( float  *sum,  float  *a1, float  *a2, long count );
void   AddDoubleArrays       ( double *sum,  double *a1, double *a2, long count );
void   AddFloatToDoubleArray ( double *sum,  float  *a1, long count );
void   AddFloatToFloatArray  ( float  *src, float *dst, long size);
void   SubFloatArrays        ( float  *diff, float  *a1, float  *a2, long count );

void   ExpandAndPadArray     ( float *array, long dx0, long dy0, long dx1, long dy1, float padValue );
void   ShrinkFloatArray      ( float *array, long dx0, long dy0, long dx1, long dy1 );
void   SubtractMeanFromArray ( float *array, long size );
void   HistoFloatArray       ( float *array, long size, double *mean, double *bkgnd );
void   ScaleDoubleArray      ( double *array, long size, double scale, double offset );
void   ScaleFloatArray       ( float *array, long size, float scale, float offset );
void   MinMaxFloatArray      ( float *array, long size, float *min, float *max );
void   GetStatsByteArray     (   signed char *array, long size,   signed char *min,   signed char *max, float *mean, float *stdv );
void   GetStatsUByteArray    ( unsigned char *array, long size, unsigned char *min, unsigned char *max, float *mean, float *stdv );
void   GetStatsWordArray     (          short *array, long size,          short *min,          short *max, float *mean, float *stdv );
void   GetStatsUWordArray    ( unsigned short *array, long size, unsigned short *min, unsigned short *max, float *mean, float *stdv );
void   GetStatsFloatArray    ( float *array, long size, float *min, float *max, float *mean, float *stdv );
void   GetStatsFloatArray2   ( float *array, long dx, long dy, float radius, float *min, float *max, float *mean, float *stdv );
void   GetStatsFloatArray3   ( float *array, long dx, long dy, float radius, float *min, float *max, float *mean, float *stdv );
void   SetFloatArrayMean     ( float *array, long size, float newMean );

void   Regress               ( float *data, float *signal, long size, double *a, double *b );
void   CalcMeanVariance      ( float *array, long size, double *average, double *variance, float maskVal );

#endif

/*****************************************************************************/
