      subroutine readorient(orient, max_views, file_name, 
     +     num_views, npix_row, npix_col, oddeven)

C     Read in the orientation, origin, and magnification information
C     from particle parameter file and store in the array orient
C
C     The parameter oddeven controls which records will be read
C     oddeven = 0, all records
C     oddeven = 1, odd records only
C     oddeven = 2, even records only
C
C     For oddeven = 1 or 2, the alternation is done across files rather
C     than on a per file basis (e.g. as if all of the particle records
C     were contatenated into a single file). This is done by toggling
C     the skipone variable which is saved between calls to readorient
C     
C     This routine is a complete rewrite of the version originally
C     written by Robert Lynch and subsequently modified by Hong Lin and
C     Yongchang Ji. (R Sinkovits 8/1/2006)

      implicit none

      character*(*), intent(in) :: file_name
      integer, intent(in)       :: oddeven
      integer, intent(in)       :: max_views, npix_row, npix_col
      integer, intent(out)      :: num_views
      real, intent(out)         :: orient(0:9, max_views )

      character(len=100) :: heading
      real theta, phi, omega, x, y, mag, score1, score2, score3
      integer i, j, ios, last_pos
      integer, save :: skipone=1
      logical complete
      character last_char

      open(unit=3, file = file_name)

C     Determine what type of file we have. Files generated by OOR or
C     earlier versions of POR are missing the last two scores and end
C     with a comma. Files generated by PPFT, PFTsearch, PCTFR, and newer
C     versions of POR have zeroes for the last two scores.

      read(3,'(A)') heading
      read(3,'(A)') heading
      read(3,'(A)') heading
      
      last_pos = len(trim(heading))
      last_char = heading(last_pos:last_pos)
      
      if(last_char == ',') then
         complete = .false.
      else
         complete = .true.
      endif

C     Rewind file
      rewind(3)

C     Discard the header lines
      read(3,'(A)') heading
      read(3,'(A)') heading

      num_views = 0

C     Loop over records in the particle orientation file. Use iostat to
C     break out of loop once end-of-file (usual case) or error is encountered.
C     For reads of just even or odd records, toggle the skipone variable so 
C     that we can continue alternating records across multiple files

      do j = 1, max_views
         if(complete) then
            read(3,*, iostat=ios) i, theta, phi, omega, x, y, mag, 
     $           score1, score2, score3
         else
            read(3,*, iostat=ios) i, theta, phi, omega, x, y, mag, 
     $           score1
            score2 = 0.0
            score3 = 0.0
         endif

         if(ios .ne. 0)    exit

         if(  (oddeven .ne. 1 .and. oddeven .ne. 2) .or.
     $        (oddeven == 1 .and. skipone == 1) .or.
     $        (oddeven == 2 .and. skipone == 0) ) then
            num_views = num_views + 1
            
            if(x <= 1)      x = npix_row/2
            if(y <= 1)      y = npix_col/2
            if(mag <= 0.01) mag = 1.0

            orient(0,num_views) = real(i)
            orient(1,num_views) = theta
            orient(2,num_views) = phi
            orient(3,num_views) = omega
            orient(4,num_views) = x
            orient(5,num_views) = y
            orient(6,num_views) = mag
            orient(7,num_views) = score1
            orient(8,num_views) = score2
            orient(9,num_views) = score3
         endif

         if(oddeven == 1 .or. oddeven == 2) then
            skipone = mod(skipone+1, 2) 
         endif
         
      enddo

      close(3)

      return
      end subroutine readorient
